Value interpolation topic

These are the most general interpolators, suitable for most values.

Functions

interpolate(Object? a, Object? b) → Object? Function(num) Value interpolation
Returns an interpolator between the two arbitrary values a and b.
interpolateBasis(List<num> values) → num Function(num) Value interpolation
Returns a uniform nonrational B-spline interpolator through the specified list of values, which must be numbers.
interpolateBasisClosed(List<num> values) → num Function(num) Value interpolation
Returns a uniform nonrational B-spline interpolator through the specified list of values, which must be numbers.
interpolateDate(DateTime a, DateTime b) → DateTime Function(num) Value interpolation
Returns an interpolator between the two dates a and b.
interpolateDiscrete(List<Object?> values) → Object? Function(num) Value interpolation
Returns a discrete interpolator for the given list of values.
interpolateList<T>(List<T> a, List<T> b) → List<Object?> Function(num) Value interpolation
Returns an interpolator between the two lists a and b.
interpolateMap<K, V>(Map<K, V> a, Map<K, V> b) → Map<K, Object?> Function(num) Value interpolation
Returns an interpolator between the two objects a and b.
interpolateNumber(num a, num b) → num Function(num) Value interpolation
Returns an interpolator between the two numbers a and b.
interpolateNumberList<T extends num>(List<T> a, List<T> b) → List<T> Function(num) Value interpolation
Returns an interpolator between the two list of numbers a and b.
interpolateRound(num a, num b) → int Function(num) Value interpolation
Returns an interpolator between the two numbers a and b; the interpolator is similar to interpolateNumber, except it will round the resulting value to the nearest integer.
interpolateString(String a, String b) → String Function(num) Value interpolation
Returns an interpolator between the two strings a and b.
piecewise<T>(List<T> values, [Object? Function(num) interpolatorFactory(T, T) = interpolate]) → Object? Function(num) Value interpolation
Returns a piecewise interpolator, composing interpolators for each adjacent pair of values.
quantize<T>(T interpolator(num), int n) → List<T> Value interpolation
Returns n uniformly-spaced samples from the specified interpolator, where n is an integer greater than one.